==> jugg-agile-middleware-rabbitmq-2.6.13.0-agile-rabbitmq-20251021.085241-11-sources.jar: com/jugg/agile/middleware/rabbitmq/spring/JaRabbitMQStartupHookHandler.java <==
package com.jugg.agile.middleware.rabbitmq.spring;

import com.jugg.agile.framework.core.dapper.log.JaLog;
import com.jugg.agile.framework.core.util.bytecode.javax.JaJavaCompilerInMemory;
import com.jugg.agile.framework.core.util.io.JaInputStreamUtil;
import com.jugg.agile.framework.core.util.io.file.JaFileReadUtil;
import com.jugg.agile.framework.core.util.reflect.clazz.loader.JaAppClassLoader;
import com.jugg.agile.framework.meta.handler.JaStartupHookHandler;

import java.io.InputStream;

/**
 * 重写MessagingMessageListenerAdapter, 适配上下文
 *
 * @author chenjian
 * @since 2025年06月25日 14:36:05
 */
public class JaRabbitMQStartupHookHandler implements JaStartupHookHandler {
    @Override
    public void start() {
        try {
//            String sourceCode = JaFileReadUtil.readAsString("sourceCode/MessagingMessageListenerAdapter.java");
//            JaJavaCompilerInMemory.compile("org.springframework.amqp.rabbit.listener.adapter.MessagingMessageListenerAdapter", sourceCode);


//            try (InputStream inputStream = ClassLoader.getSystemResourceAsStream("sourceCode/MessagingMessageListenerAdapter.class")) {
//                assert inputStream != null;
//                JaAppClassLoader.defineClass("org.springframework.amqp.rabbit.listener.adapter.MessagingMessageListenerAdapter"
//                        , JaInputStreamUtil.read3(inputStream));
//            } catch (Throwable e) {
//                JaLog.error("sourceCode/MessagingMessageListenerAdapter.class defineClass error:{}", e.getMessage());
//            }
        } catch (Throwable e) {
            JaLog.error("MessagingMessageListenerAdapter compile error", e);
        }


    }
}

==> jugg-agile-middleware-rabbitmq-4.0-agile-rabbitmq-20250828.061306-34-sources.jar: com/jugg/agile/middleware/rabbitmq/spring/JaRabbitMQStartupHookHandler.java <==
package com.jugg.agile.middleware.rabbitmq.spring;

import com.jugg.agile.framework.core.dapper.log.JaLog;
import com.jugg.agile.framework.core.util.bytecode.javax.JaJavaCompilerInMemory;
import com.jugg.agile.framework.core.util.io.JaInputStreamUtil;
import com.jugg.agile.framework.core.util.io.file.JaFileReadUtil;
import com.jugg.agile.framework.core.util.reflect.clazz.loader.JaAppClassLoader;
import com.jugg.agile.framework.meta.handler.JaStartupHookHandler;

import java.io.InputStream;

/**
 * 重写MessagingMessageListenerAdapter, 适配上下文
 *
 * @author chenjian
 * @since 2025年06月25日 14:36:05
 */
public class JaRabbitMQStartupHookHandler implements JaStartupHookHandler {
    @Override
    public void start() {
        try {
//            String sourceCode = JaFileReadUtil.readAsString("sourceCode/MessagingMessageListenerAdapter.java");
//            JaJavaCompilerInMemory.compile("org.springframework.amqp.rabbit.listener.adapter.MessagingMessageListenerAdapter", sourceCode);


            try (InputStream inputStream = ClassLoader.getSystemResourceAsStream("sourceCode/MessagingMessageListenerAdapter.class")) {
                assert inputStream != null;
                JaAppClassLoader.defineClass("org.springframework.amqp.rabbit.listener.adapter.MessagingMessageListenerAdapter"
                        , JaInputStreamUtil.read3(inputStream));
            } catch (Throwable e) {
                JaLog.error("sourceCode/MessagingMessageListenerAdapter.class defineClass error:{}", e.getMessage());
            }
        } catch (Throwable e) {
            JaLog.error("MessagingMessageListenerAdapter compile error", e);
        }


    }
}
